@@ -27,6 +27,7 @@ coerce "$type.DBIHandleGenerator" => from "$type.DBIHandle" => via {
     sub { $dbh }
 };
 
+has 'db_name'      => ( is => 'rw', isa => 'Str' );
 has 'dbh'          => ( is => 'ro', isa => "$type.DBIHandleGenerator", coerce => 1 );
 has 'dbh_ro'       => ( is => 'ro', isa => "$type.DBIHandleGenerator", predicate => 'has_dbh_ro', coerce => 1 );
 has 'sql_strings'  => ( is => 'rw', isa => 'HashRef', lazy_build => 1 );
@@ -39,6 +40,7 @@ sub BUILD {
 
     my $dbh = $self->dbh->();
 
+    $self->db_name( $dbh->get_info( $GetInfoType{SQL_DBMS_NAME} ) );
     $self->sql_strings;
 
     if ( $args->{create_table} ) {
@@ -58,11 +60,10 @@ sub _table {
 sub _build_sql_strings {
     my ( $self, ) = @_;
 
-    my $dbh     = $self->dbh->();
-    my $table   = $dbh->quote_identifier( $self->_table );
-    my $value   = $dbh->quote_identifier('value');
-    my $key     = $dbh->quote_identifier('key');
-    my $db_name = $dbh->get_info( $GetInfoType{SQL_DBMS_NAME} );
+    my $dbh   = $self->dbh->();
+    my $table = $dbh->quote_identifier( $self->_table );
+    my $value = $dbh->quote_identifier('value');
+    my $key   = $dbh->quote_identifier('key');
 
     my $strings = {
         fetch    => "SELECT $value FROM $table WHERE $key = ?",
@@ -76,7 +77,7 @@ sub _build_sql_strings {
           . " PRIMARY KEY ( $key ) )",
     };
 
-    if ( $db_name eq 'MySQL' ) {
+    if ( $self->db_name eq 'MySQL' ) {
         $strings->{store} =
             "INSERT INTO $table"
           . " ( $key, $value )"
@@ -84,13 +85,19 @@ sub _build_sql_strings {
           . " ON DUPLICATE KEY UPDATE $value=VALUES($value)";
         delete $strings->{store2};
     }
-    elsif ( $db_name eq 'SQLite' ) {
+    elsif ( $self->db_name eq 'SQLite' ) {
         $strings->{store} =
             "INSERT OR REPLACE INTO $table"
           . " ( $key, $value )"
           . " values ( ?, ? )";
         delete $strings->{store2};
     }
+    elsif ( $self->db_name eq 'PostgreSQL' ) {
+        $strings->{create} =
+            "CREATE TABLE IF NOT EXISTS $table ("
+          . " $key BYTEA, $value BYTEA,"
+          . " PRIMARY KEY ( $key ) )";
+    }
 
     return $strings;
 }
@@ -101,6 +108,9 @@ sub fetch {
     my $dbh = $self->has_dbh_ro ? $self->dbh_ro->() : $self->dbh->();
     my $sth = $dbh->prepare_cached( $self->sql_strings->{fetch} )
       or croak $dbh->errstr;
+    if ( $self->db_name eq 'PostgreSQL' ) {
+        $sth->bind_param( 1, undef, { pg_type => DBD::Pg::PG_BYTEA() } );
+    }
     $sth->execute($key) or croak $sth->errstr;
     my $results = $sth->fetchall_arrayref;
 
@@ -112,10 +122,20 @@ sub store {
 
     my $dbh = $self->dbh->();
     my $sth = $dbh->prepare_cached( $self->sql_strings->{store} );
+    if ( $self->db_name eq 'PostgreSQL' ) {
+        $sth->bind_param( 1, undef, { pg_type => DBD::Pg::PG_BYTEA() } );
+        $sth->bind_param( 2, undef, { pg_type => DBD::Pg::PG_BYTEA() } );
+    }
     if ( not $sth->execute( $key, $data ) ) {
         if ( $self->sql_strings->{store2} ) {
             my $sth = $dbh->prepare_cached( $self->sql_strings->{store2} )
               or croak $dbh->errstr;
+            if ( $self->db_name eq 'PostgreSQL' ) {
+                $sth->bind_param( 1, undef,
+                    { pg_type => DBD::Pg::PG_BYTEA() } );
+                $sth->bind_param( 2, undef,
+                    { pg_type => DBD::Pg::PG_BYTEA() } );
+            }
             $sth->execute( $data, $key )
               or croak $sth->errstr;
         }
@@ -134,6 +154,9 @@ sub remove {
     my $dbh = $self->dbh->();
     my $sth = $dbh->prepare_cached( $self->sql_strings->{remove} )
       or croak $dbh->errstr;
+    if ( $self->db_name eq 'PostgreSQL' ) {
+        $sth->bind_param( 1, undef, { pg_type => DBD::Pg::PG_BYTEA() } );
+    }
     $sth->execute($key) or croak $sth->errstr;
     $sth->finish;
 
@@ -171,7 +194,7 @@ sub get_namespaces { croak 'not supported' }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -181,7 +204,7 @@ CHI::Driver::DBI - Use DBI for cache storage
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -247,8 +270,8 @@ the cache will be stored in a table called C<chi_Default>.
 =item table_prefix
 
 This is the prefix that is used when building a table name.  If you want to
-just use the namespace as a literal table name, set this to undef.  Defaults to
-C<chi_>.
+just use the namespace as a literal table name, set this to the empty string. 
+Defaults to C<chi_>.
 
 =item dbh
 
@@ -301,7 +324,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
